searchData={"items":[{"type":"behaviour","title":"OpenAI.Agent","doc":"Defines the behavior for OpenAI agents.\n\nAn agent is a module that can process inputs, use tools, delegate to other agents,\nand produce structured outputs.","ref":"OpenAI.Agent.html"},{"type":"behaviour","title":"Example - OpenAI.Agent","doc":"defmodule MyApp.WeatherAgent do\n      use OpenAI.Agent\n      \n      @impl true\n      def configure do\n        %{\n          name: \"weather_assistant\",\n          instructions: \"You are a helpful weather assistant.\",\n          model: \"gpt-4.1-mini\",\n          tools: [MyApp.Tools.GetWeather],\n          output_schema: MyApp.Schemas.WeatherReport\n        }\n      end\n      \n      @impl true\n      def on_start(context, agent_state) do\n        # Optional lifecycle callback\n        {:ok, agent_state}\n      end\n    end","ref":"OpenAI.Agent.html#module-example"},{"type":"type","title":"OpenAI.Agent.agent_config/0","doc":"","ref":"OpenAI.Agent.html#t:agent_config/0"},{"type":"type","title":"OpenAI.Agent.agent_state/0","doc":"","ref":"OpenAI.Agent.html#t:agent_state/0"},{"type":"callback","title":"OpenAI.Agent.configure/0","doc":"","ref":"OpenAI.Agent.html#c:configure/0"},{"type":"type","title":"OpenAI.Agent.context/0","doc":"","ref":"OpenAI.Agent.html#t:context/0"},{"type":"function","title":"OpenAI.Agent.get_config/1","doc":"Gets the configuration for an agent module.","ref":"OpenAI.Agent.html#get_config/1"},{"type":"function","title":"OpenAI.Agent.get_instructions/2","doc":"Gets the instructions for an agent, resolving dynamic instructions if needed.","ref":"OpenAI.Agent.html#get_instructions/2"},{"type":"callback","title":"OpenAI.Agent.on_end/2","doc":"","ref":"OpenAI.Agent.html#c:on_end/2"},{"type":"callback","title":"OpenAI.Agent.on_start/2","doc":"","ref":"OpenAI.Agent.html#c:on_start/2"},{"type":"function","title":"OpenAI.Agent.validate_agent/1","doc":"Validates an agent module has the required callbacks.","ref":"OpenAI.Agent.html#validate_agent/1"},{"type":"module","title":"OpenAI.Agents","doc":"OpenAI Agents is an Elixir library for building AI agents using OpenAI's Responses API.\n\nThis library provides a powerful, idiomatic Elixir framework for creating agents that can:\n- Use tools to perform actions\n- Hand off conversations to other specialized agents\n- Validate inputs and outputs with guardrails\n- Stream responses in real-time\n- Maintain conversation context","ref":"OpenAI.Agents.html"},{"type":"module","title":"Quick Start - OpenAI.Agents","doc":"defmodule MyApp.Assistant do\n      use OpenAI.Agent\n      \n      @impl true\n      def configure do\n        %{\n          name: \"assistant\",\n          instructions: \"You are a helpful assistant.\",\n          tools: [MyApp.Tools.Calculator]\n        }\n      end\n    end\n    \n    # Run the agent\n    {:ok, result} = OpenAI.Agents.run(MyApp.Assistant, \"What is 2 + 2?\")\n    IO.puts(result.output)","ref":"OpenAI.Agents.html#module-quick-start"},{"type":"function","title":"OpenAI.Agents.run/3","doc":"Runs an agent synchronously with the given input.","ref":"OpenAI.Agents.html#run/3"},{"type":"function","title":"Options - OpenAI.Agents.run/3","doc":"* `:context` - Application-specific context to pass through execution\n  * `:config` - Runtime configuration overrides\n  * `:timeout` - Maximum time to wait for completion (default: 60000ms)\n  * `:previous_response_id` - Response ID from previous turn to continue conversation","ref":"OpenAI.Agents.html#run/3-options"},{"type":"function","title":"Examples - OpenAI.Agents.run/3","doc":"OpenAI.Agents.run(MyAgent, \"Hello\")\n    OpenAI.Agents.run(MyAgent, \"Hello\", context: %{user_id: \"123\"})\n    \n    # Multi-turn conversation\n    {:ok, result1} = OpenAI.Agents.run(MyAgent, \"My name is Alice\")\n    {:ok, result2} = OpenAI.Agents.run(MyAgent, \"What's my name?\", \n                                       previous_response_id: result1.response_id)","ref":"OpenAI.Agents.html#run/3-examples"},{"type":"function","title":"OpenAI.Agents.run_async/3","doc":"Runs an agent asynchronously, returning a Task.","ref":"OpenAI.Agents.html#run_async/3"},{"type":"function","title":"Options - OpenAI.Agents.run_async/3","doc":"Same as `run/3`.","ref":"OpenAI.Agents.html#run_async/3-options"},{"type":"function","title":"Examples - OpenAI.Agents.run_async/3","doc":"task = OpenAI.Agents.run_async(MyAgent, \"Hello\")\n    {:ok, result} = Task.await(task)","ref":"OpenAI.Agents.html#run_async/3-examples"},{"type":"function","title":"OpenAI.Agents.stream/3","doc":"Streams an agent's responses in real-time.\n\nReturns a Stream that emits events as the agent processes the input.","ref":"OpenAI.Agents.html#stream/3"},{"type":"function","title":"Options - OpenAI.Agents.stream/3","doc":"Same as `run/3`.","ref":"OpenAI.Agents.html#stream/3-options"},{"type":"function","title":"Examples - OpenAI.Agents.stream/3","doc":"MyAgent\n    |> OpenAI.Agents.stream(\"Tell me a story\")\n    |> Enum.each(fn event ->\n      case event do\n        %TextDelta{text: text} -> IO.write(text)\n        %ToolCall{name: name} -> IO.puts(\"\\nCalling tool: #{name}\")\n        _ -> :ok\n      end\n    end)","ref":"OpenAI.Agents.html#stream/3-examples"},{"type":"module","title":"OpenAI.Agents.Context","doc":"Manages context state throughout agent execution.\n\nContext provides a way to pass application-specific state through\nthe entire agent execution pipeline, accessible to tools, guardrails,\nand lifecycle hooks.","ref":"OpenAI.Agents.Context.html"},{"type":"function","title":"OpenAI.Agents.Context.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"OpenAI.Agents.Context.html#child_spec/1"},{"type":"function","title":"OpenAI.Agents.Context.get/1","doc":"Gets the current context from the server.","ref":"OpenAI.Agents.Context.html#get/1"},{"type":"function","title":"OpenAI.Agents.Context.get_metadata/3","doc":"Gets metadata.","ref":"OpenAI.Agents.Context.html#get_metadata/3"},{"type":"function","title":"OpenAI.Agents.Context.get_user_context/1","doc":"Gets the user context.","ref":"OpenAI.Agents.Context.html#get_user_context/1"},{"type":"function","title":"OpenAI.Agents.Context.new/0","doc":"Creates a new context with default values.","ref":"OpenAI.Agents.Context.html#new/0"},{"type":"function","title":"OpenAI.Agents.Context.set_metadata/3","doc":"Sets metadata.","ref":"OpenAI.Agents.Context.html#set_metadata/3"},{"type":"function","title":"OpenAI.Agents.Context.start_link/1","doc":"Starts a context server for managing mutable state during execution.","ref":"OpenAI.Agents.Context.html#start_link/1"},{"type":"type","title":"OpenAI.Agents.Context.t/0","doc":"","ref":"OpenAI.Agents.Context.html#t:t/0"},{"type":"function","title":"OpenAI.Agents.Context.update/2","doc":"Updates the context in the server.","ref":"OpenAI.Agents.Context.html#update/2"},{"type":"function","title":"OpenAI.Agents.Context.update_usage/2","doc":"Updates usage statistics.","ref":"OpenAI.Agents.Context.html#update_usage/2"},{"type":"function","title":"OpenAI.Agents.Context.wrap/1","doc":"Wraps user-provided context.","ref":"OpenAI.Agents.Context.html#wrap/1"},{"type":"behaviour","title":"OpenAI.Agents.Context.Behaviour","doc":"Optional behavior for custom context implementations.","ref":"OpenAI.Agents.Context.Behaviour.html"},{"type":"callback","title":"OpenAI.Agents.Context.Behaviour.init/1","doc":"","ref":"OpenAI.Agents.Context.Behaviour.html#c:init/1"},{"type":"callback","title":"OpenAI.Agents.Context.Behaviour.validate/1","doc":"","ref":"OpenAI.Agents.Context.Behaviour.html#c:validate/1"},{"type":"module","title":"OpenAI.Agents.Events","doc":"Event types emitted during streaming operations.","ref":"OpenAI.Agents.Events.html"},{"type":"module","title":"OpenAI.Agents.Events.FunctionCallArgumentsDelta","doc":"Emitted for function call argument chunks","ref":"OpenAI.Agents.Events.FunctionCallArgumentsDelta.html"},{"type":"module","title":"OpenAI.Agents.Events.ResponseCompleted","doc":"Emitted when a response completes","ref":"OpenAI.Agents.Events.ResponseCompleted.html"},{"type":"module","title":"OpenAI.Agents.Events.ResponseCreated","doc":"Emitted when a response starts","ref":"OpenAI.Agents.Events.ResponseCreated.html"},{"type":"module","title":"OpenAI.Agents.Events.StreamComplete","doc":"Emitted when the stream ends","ref":"OpenAI.Agents.Events.StreamComplete.html"},{"type":"module","title":"OpenAI.Agents.Events.TextDelta","doc":"Emitted for text chunks","ref":"OpenAI.Agents.Events.TextDelta.html"},{"type":"module","title":"OpenAI.Agents.Events.ToolCall","doc":"Emitted when a tool is called","ref":"OpenAI.Agents.Events.ToolCall.html"},{"type":"module","title":"OpenAI.Agents.Events.Unknown","doc":"Emitted for unrecognized event types","ref":"OpenAI.Agents.Events.Unknown.html"},{"type":"module","title":"OpenAI.Agents.Events.UsageUpdate","doc":"Emitted with token usage updates","ref":"OpenAI.Agents.Events.UsageUpdate.html"},{"type":"behaviour","title":"OpenAI.Agents.Guardrail","doc":"Defines the behavior for guardrails that validate agent inputs and outputs.\n\nGuardrails can halt agent execution if they detect problematic content.","ref":"OpenAI.Agents.Guardrail.html"},{"type":"behaviour","title":"Example - OpenAI.Agents.Guardrail","doc":"defmodule MyApp.Guardrails.ContentFilter do\n      use OpenAI.Agents.Guardrail\n      \n      @impl true\n      def validate_input(input, context) do\n        if contains_prohibited_content?(input) do\n          {:error, \"Prohibited content detected\", %{reason: \"content_policy\"}}\n        else\n          :ok\n        end\n      end\n      \n      @impl true\n      def validate_output(output, context) do\n        :ok\n      end\n    end","ref":"OpenAI.Agents.Guardrail.html#module-example"},{"type":"type","title":"OpenAI.Agents.Guardrail.context/0","doc":"","ref":"OpenAI.Agents.Guardrail.html#t:context/0"},{"type":"type","title":"OpenAI.Agents.Guardrail.input/0","doc":"","ref":"OpenAI.Agents.Guardrail.html#t:input/0"},{"type":"type","title":"OpenAI.Agents.Guardrail.output/0","doc":"","ref":"OpenAI.Agents.Guardrail.html#t:output/0"},{"type":"function","title":"OpenAI.Agents.Guardrail.run_input_guardrails/3","doc":"Runs input guardrails on the given input.","ref":"OpenAI.Agents.Guardrail.html#run_input_guardrails/3"},{"type":"function","title":"OpenAI.Agents.Guardrail.run_output_guardrails/3","doc":"Runs output guardrails on the given output.","ref":"OpenAI.Agents.Guardrail.html#run_output_guardrails/3"},{"type":"function","title":"OpenAI.Agents.Guardrail.validate_guardrail/1","doc":"Validates a guardrail module has the correct structure.","ref":"OpenAI.Agents.Guardrail.html#validate_guardrail/1"},{"type":"callback","title":"OpenAI.Agents.Guardrail.validate_input/2","doc":"","ref":"OpenAI.Agents.Guardrail.html#c:validate_input/2"},{"type":"callback","title":"OpenAI.Agents.Guardrail.validate_output/2","doc":"","ref":"OpenAI.Agents.Guardrail.html#c:validate_output/2"},{"type":"type","title":"OpenAI.Agents.Guardrail.validation_result/0","doc":"","ref":"OpenAI.Agents.Guardrail.html#t:validation_result/0"},{"type":"module","title":"OpenAI.Agents.Handoff","doc":"Manages handoffs between agents.\n\nHandoffs allow one agent to delegate control to another agent,\noptionally filtering the conversation history.","ref":"OpenAI.Agents.Handoff.html"},{"type":"function","title":"OpenAI.Agents.Handoff.create/2","doc":"Creates a handoff configuration.","ref":"OpenAI.Agents.Handoff.html#create/2"},{"type":"function","title":"OpenAI.Agents.Handoff.execute/3","doc":"Executes a handoff.","ref":"OpenAI.Agents.Handoff.html#execute/3"},{"type":"macro","title":"OpenAI.Agents.Handoff.handoff/2","doc":"Creates a handoff tool module dynamically.","ref":"OpenAI.Agents.Handoff.html#handoff/2"},{"type":"type","title":"OpenAI.Agents.Handoff.handoff_config/0","doc":"","ref":"OpenAI.Agents.Handoff.html#t:handoff_config/0"},{"type":"function","title":"OpenAI.Agents.Handoff.to_tool_schema/1","doc":"Converts a handoff to a tool schema for use in the API.","ref":"OpenAI.Agents.Handoff.html#to_tool_schema/1"},{"type":"behaviour","title":"OpenAI.Agents.Models.Adapter","doc":"Behavior for model adapters.","ref":"OpenAI.Agents.Models.Adapter.html"},{"type":"callback","title":"OpenAI.Agents.Models.Adapter.create_completion/2","doc":"","ref":"OpenAI.Agents.Models.Adapter.html#c:create_completion/2"},{"type":"callback","title":"OpenAI.Agents.Models.Adapter.create_stream/2","doc":"","ref":"OpenAI.Agents.Models.Adapter.html#c:create_stream/2"},{"type":"module","title":"OpenAI.Agents.Models.ResponsesAdapter","doc":"Adapter for the OpenAI Responses API.\n\nHandles communication with the /v1/responses endpoint, including\nboth standard and streaming requests.","ref":"OpenAI.Agents.Models.ResponsesAdapter.html"},{"type":"module","title":"OpenAI.Agents.Runner","doc":"Manages the execution of agents, handling the conversation loop,\ntool execution, handoffs, and streaming.","ref":"OpenAI.Agents.Runner.html"},{"type":"function","title":"OpenAI.Agents.Runner.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"OpenAI.Agents.Runner.html#child_spec/1"},{"type":"function","title":"OpenAI.Agents.Runner.run/3","doc":"Runs an agent synchronously.","ref":"OpenAI.Agents.Runner.html#run/3"},{"type":"function","title":"OpenAI.Agents.Runner.run_async/3","doc":"Runs an agent asynchronously.","ref":"OpenAI.Agents.Runner.html#run_async/3"},{"type":"function","title":"OpenAI.Agents.Runner.start_link/3","doc":"","ref":"OpenAI.Agents.Runner.html#start_link/3"},{"type":"function","title":"OpenAI.Agents.Runner.stream/3","doc":"Streams agent responses.","ref":"OpenAI.Agents.Runner.html#stream/3"},{"type":"module","title":"OpenAI.Agents.StreamHandler","doc":"Handles streaming responses using GenStage for backpressure management.","ref":"OpenAI.Agents.StreamHandler.html"},{"type":"function","title":"OpenAI.Agents.StreamHandler.complete/1","doc":"Marks the stream as complete.","ref":"OpenAI.Agents.StreamHandler.html#complete/1"},{"type":"function","title":"OpenAI.Agents.StreamHandler.emit/2","doc":"Emits an event to the stream.","ref":"OpenAI.Agents.StreamHandler.html#emit/2"},{"type":"function","title":"OpenAI.Agents.StreamHandler.next_event/2","doc":"Gets the next event from the stream.","ref":"OpenAI.Agents.StreamHandler.html#next_event/2"},{"type":"function","title":"OpenAI.Agents.StreamHandler.start_link/1","doc":"Starts a new stream handler.","ref":"OpenAI.Agents.StreamHandler.html#start_link/1"},{"type":"module","title":"OpenAI.Agents.Telemetry","doc":"Telemetry integration for OpenAI Agents.\n\nEmits telemetry events for agent execution, tool calls, and API requests.","ref":"OpenAI.Agents.Telemetry.html"},{"type":"module","title":"Events - OpenAI.Agents.Telemetry","doc":"* `[:openai_agents, :run, :start]` - Emitted when an agent run starts\n* `[:openai_agents, :run, :stop]` - Emitted when an agent run completes\n* `[:openai_agents, :agent, :start]` - Emitted when an agent starts processing\n* `[:openai_agents, :agent, :stop]` - Emitted when an agent completes processing\n* `[:openai_agents, :tool, :start]` - Emitted when a tool execution starts\n* `[:openai_agents, :tool, :stop]` - Emitted when a tool execution completes\n* `[:openai_agents, :handoff, :start]` - Emitted when a handoff starts\n* `[:openai_agents, :api, :request, :start]` - Emitted when an API request starts\n* `[:openai_agents, :api, :request, :stop]` - Emitted when an API request completes","ref":"OpenAI.Agents.Telemetry.html#module-events"},{"type":"module","title":"Measurements - OpenAI.Agents.Telemetry","doc":"All `:stop` events include a `:duration` measurement in native time units.","ref":"OpenAI.Agents.Telemetry.html#module-measurements"},{"type":"module","title":"Metadata - OpenAI.Agents.Telemetry","doc":"Events include relevant metadata such as:\n* `:agent_module` - The agent module\n* `:trace_id` - The trace ID for the run\n* `:tool_name` - The name of the tool being executed\n* `:status` - `:ok` or `:error`","ref":"OpenAI.Agents.Telemetry.html#module-metadata"},{"type":"function","title":"OpenAI.Agents.Telemetry.handoff/3","doc":"Emits a handoff event.","ref":"OpenAI.Agents.Telemetry.html#handoff/3"},{"type":"function","title":"OpenAI.Agents.Telemetry.setup/0","doc":"Sets up default telemetry handlers.","ref":"OpenAI.Agents.Telemetry.html#setup/0"},{"type":"function","title":"OpenAI.Agents.Telemetry.start_agent/2","doc":"Emits an agent start event.","ref":"OpenAI.Agents.Telemetry.html#start_agent/2"},{"type":"function","title":"OpenAI.Agents.Telemetry.start_api_request/3","doc":"Emits an API request start event.","ref":"OpenAI.Agents.Telemetry.html#start_api_request/3"},{"type":"function","title":"OpenAI.Agents.Telemetry.start_run/1","doc":"Emits a run start event.","ref":"OpenAI.Agents.Telemetry.html#start_run/1"},{"type":"function","title":"OpenAI.Agents.Telemetry.start_tool/2","doc":"Emits a tool start event.","ref":"OpenAI.Agents.Telemetry.html#start_tool/2"},{"type":"function","title":"OpenAI.Agents.Telemetry.stop_agent/4","doc":"Emits an agent stop event.","ref":"OpenAI.Agents.Telemetry.html#stop_agent/4"},{"type":"function","title":"OpenAI.Agents.Telemetry.stop_api_request/6","doc":"Emits an API request stop event.","ref":"OpenAI.Agents.Telemetry.html#stop_api_request/6"},{"type":"function","title":"OpenAI.Agents.Telemetry.stop_run/2","doc":"Emits a run stop event.","ref":"OpenAI.Agents.Telemetry.html#stop_run/2"},{"type":"function","title":"OpenAI.Agents.Telemetry.stop_tool/3","doc":"Emits a tool stop event.","ref":"OpenAI.Agents.Telemetry.html#stop_tool/3"},{"type":"behaviour","title":"OpenAI.Agents.Tool","doc":"Defines the behavior for tools that agents can use.\n\nTools are modules that implement specific functionality that agents can call\nduring their execution.","ref":"OpenAI.Agents.Tool.html"},{"type":"behaviour","title":"Example - OpenAI.Agents.Tool","doc":"defmodule MyApp.Tools.GetWeather do\n      use OpenAI.Agents.Tool\n      \n      @impl true\n      def schema do\n        %{\n          name: \"get_weather\",\n          description: \"Get the current weather for a city\",\n          parameters: %{\n            type: \"object\",\n            properties: %{\n              city: %{type: \"string\", description: \"The city name\"}\n            },\n            required: [\"city\"]\n          }\n        }\n      end\n      \n      @impl true\n      def execute(%{\"city\" => city}, context) do\n        case WeatherAPI.get_weather(city) do\n          {:ok, data} -> {:ok, data}\n          {:error, reason} -> {:error, \"Failed to get weather: #{reason}\"}\n        end\n      end\n    end","ref":"OpenAI.Agents.Tool.html#module-example"},{"type":"type","title":"OpenAI.Agents.Tool.context/0","doc":"","ref":"OpenAI.Agents.Tool.html#t:context/0"},{"type":"callback","title":"OpenAI.Agents.Tool.execute/2","doc":"","ref":"OpenAI.Agents.Tool.html#c:execute/2"},{"type":"callback","title":"OpenAI.Agents.Tool.on_error/3","doc":"","ref":"OpenAI.Agents.Tool.html#c:on_error/3"},{"type":"type","title":"OpenAI.Agents.Tool.params/0","doc":"","ref":"OpenAI.Agents.Tool.html#t:params/0"},{"type":"type","title":"OpenAI.Agents.Tool.result/0","doc":"","ref":"OpenAI.Agents.Tool.html#t:result/0"},{"type":"callback","title":"OpenAI.Agents.Tool.schema/0","doc":"","ref":"OpenAI.Agents.Tool.html#c:schema/0"},{"type":"type","title":"OpenAI.Agents.Tool.schema/0","doc":"","ref":"OpenAI.Agents.Tool.html#t:schema/0"},{"type":"function","title":"OpenAI.Agents.Tool.to_openai_format/1","doc":"Converts a tool module to the OpenAI tool schema format.","ref":"OpenAI.Agents.Tool.html#to_openai_format/1"},{"type":"function","title":"OpenAI.Agents.Tool.validate_tool/1","doc":"Validates a tool module has the required callbacks and schema structure.","ref":"OpenAI.Agents.Tool.html#validate_tool/1"},{"type":"module","title":"OpenAI.Agents.ToolExecutor","doc":"Executes tools in parallel or serially based on their type.\nHandles error recovery and telemetry.","ref":"OpenAI.Agents.ToolExecutor.html"},{"type":"function","title":"OpenAI.Agents.ToolExecutor.execute_parallel/3","doc":"Executes multiple function calls in parallel.\n\nReturns a list of {call_id, result} tuples.","ref":"OpenAI.Agents.ToolExecutor.html#execute_parallel/3"},{"type":"function","title":"OpenAI.Agents.ToolExecutor.execute_single/3","doc":"Executes a single function call.","ref":"OpenAI.Agents.ToolExecutor.html#execute_single/3"},{"type":"module","title":"OpenAI.Agents.TraceCollector","doc":"Collects and manages trace data for agent runs.","ref":"OpenAI.Agents.TraceCollector.html"},{"type":"function","title":"OpenAI.Agents.TraceCollector.add_span/2","doc":"","ref":"OpenAI.Agents.TraceCollector.html#add_span/2"},{"type":"function","title":"OpenAI.Agents.TraceCollector.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"OpenAI.Agents.TraceCollector.html#child_spec/1"},{"type":"function","title":"OpenAI.Agents.TraceCollector.end_trace/1","doc":"","ref":"OpenAI.Agents.TraceCollector.html#end_trace/1"},{"type":"function","title":"OpenAI.Agents.TraceCollector.get_trace/1","doc":"","ref":"OpenAI.Agents.TraceCollector.html#get_trace/1"},{"type":"function","title":"OpenAI.Agents.TraceCollector.start_link/1","doc":"","ref":"OpenAI.Agents.TraceCollector.html#start_link/1"},{"type":"function","title":"OpenAI.Agents.TraceCollector.start_trace/2","doc":"","ref":"OpenAI.Agents.TraceCollector.html#start_trace/2"},{"type":"module","title":"OpenAI.Agents.TracingSupervisor","doc":"Supervisor for tracing components.","ref":"OpenAI.Agents.TracingSupervisor.html"},{"type":"function","title":"OpenAI.Agents.TracingSupervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"OpenAI.Agents.TracingSupervisor.html#child_spec/1"},{"type":"function","title":"OpenAI.Agents.TracingSupervisor.start_link/1","doc":"","ref":"OpenAI.Agents.TracingSupervisor.html#start_link/1"},{"type":"module","title":"OpenAI.Agents.Usage","doc":"Tracks token usage throughout agent execution.","ref":"OpenAI.Agents.Usage.html"},{"type":"function","title":"OpenAI.Agents.Usage.add/2","doc":"Adds usage from an API response to existing usage.","ref":"OpenAI.Agents.Usage.html#add/2"},{"type":"function","title":"OpenAI.Agents.Usage.new/0","doc":"Creates a new usage struct.","ref":"OpenAI.Agents.Usage.html#new/0"},{"type":"type","title":"OpenAI.Agents.Usage.t/0","doc":"","ref":"OpenAI.Agents.Usage.html#t:t/0"},{"type":"function","title":"OpenAI.Agents.Usage.to_map/1","doc":"Converts usage to a plain map.","ref":"OpenAI.Agents.Usage.html#to_map/1"},{"type":"extras","title":"OpenAI Agents for Elixir","doc":"# OpenAI Agents for Elixir\n\nBuild powerful AI agents in Elixir using OpenAI's Responses API. This library provides an idiomatic Elixir framework for creating agents that can use tools, delegate tasks to specialized agents, and maintain conversations with full type safety and fault tolerance.","ref":"readme.html"},{"type":"extras","title":"Table of Contents - OpenAI Agents for Elixir","doc":"- [Installation](#installation)\n- [Setup](#setup)\n- [Basic Usage](#basic-usage)\n- [Core Concepts](#core-concepts)\n- [Examples](#examples)\n- [Elixir-Specific Features](#elixir-specific-features)\n- [API Reference](#api-reference)\n- [Configuration](#configuration)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Installation - OpenAI Agents for Elixir","doc":"Add `openai_agents` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:openai_agents, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen run:\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Publishing to Hex - OpenAI Agents for Elixir","doc":"This package is published to [hex.pm](https://hex.pm/packages/openai_agents) for easy installation in Elixir projects.","ref":"readme.html#publishing-to-hex"},{"type":"extras","title":"For Maintainers - OpenAI Agents for Elixir","doc":"To publish a new version to hex.pm:\n\n1. Ensure all tests pass and the working directory is clean:\n   ```bash\n   mix test\n   mix lint\n   git status  # should show no uncommitted changes\n   ```\n\n2. Update the version in `mix.exs`\n\n3. Commit and tag the release:\n   ```bash\n   git add mix.exs\n   git commit -m \"Bump version to X.Y.Z\"\n   git tag -a vX.Y.Z -m \"Release X.Y.Z\"\n   ```\n\n4. Build and publish:\n   ```bash\n   mix hex.build\n   mix hex.publish\n   ```\n\n5. Push changes:\n   ```bash\n   git push origin main --tags\n   ```","ref":"readme.html#for-maintainers"},{"type":"extras","title":"Prerequisites - OpenAI Agents for Elixir","doc":"- You must be authenticated with hex.pm: `mix hex.user auth`\n- You must be added as a package owner (for subsequent releases)","ref":"readme.html#prerequisites"},{"type":"extras","title":"Setup - OpenAI Agents for Elixir","doc":"","ref":"readme.html#setup"},{"type":"extras","title":"1. Configure your OpenAI API key - OpenAI Agents for Elixir","doc":"#### For Development/Test\n\nCreate a `.env` file in your project root (copy from `.env.example`):\n```bash\ncp .env.example .env\n```\n\nThen edit `.env` and add your API key:\n```bash\nOPENAI_API_KEY=your-api-key-here\n```\n\nThe library will automatically load this file in development and test environments.\n\n#### For Production\n\nSet your API key as an environment variable:\n```bash\nexport OPENAI_API_KEY=\"your-api-key\"\n```\n\nOr configure it in your `config/runtime.exs`:\n```elixir\nconfig :openai_agents,\n  api_key: System.get_env(\"OPENAI_API_KEY\"),\n  default_model: \"gpt-4o\"\n```","ref":"readme.html#1-configure-your-openai-api-key"},{"type":"extras","title":"2. Start the application - OpenAI Agents for Elixir","doc":"If you're using Phoenix or another OTP application, the library will start automatically. For standalone usage, add to your application's supervision tree:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    # ... your other children\n    {OpenAI.Agents.Application, []}\n  ]\n  \n  Supervisor.start_link(children, strategy: :one_for_one)\nend\n```","ref":"readme.html#2-start-the-application"},{"type":"extras","title":"Basic Usage - OpenAI Agents for Elixir","doc":"","ref":"readme.html#basic-usage"},{"type":"extras","title":"Creating Your First Agent - OpenAI Agents for Elixir","doc":"```elixir\ndefmodule MyApp.Assistant do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"assistant\",\n      instructions: \"You are a helpful assistant that responds concisely.\"\n    }\n  end\nend\n\n# Run the agent\n{:ok, result} = OpenAI.Agents.run(MyApp.Assistant, \"What is the capital of France?\")\nIO.puts(result.output)\n# => \"The capital of France is Paris.\"\n```","ref":"readme.html#creating-your-first-agent"},{"type":"extras","title":"Core Functions - OpenAI Agents for Elixir","doc":"The library provides three main ways to interact with agents:\n\n```elixir\n# 1. Synchronous execution (blocking)\n{:ok, result} = OpenAI.Agents.run(agent_module, input, opts \\\\ [])\n\n# 2. Asynchronous execution (returns a Task)\ntask = OpenAI.Agents.run_async(agent_module, input, opts \\\\ [])\n{:ok, result} = Task.await(task)\n\n# 3. Streaming execution (returns a Stream)\nstream = OpenAI.Agents.stream(agent_module, input, opts \\\\ [])\n```","ref":"readme.html#core-functions"},{"type":"extras","title":"Core Concepts - OpenAI Agents for Elixir","doc":"","ref":"readme.html#core-concepts"},{"type":"extras","title":"Agents - OpenAI Agents for Elixir","doc":"Agents are modules that implement the `OpenAI.Agent` behaviour:\n\n```elixir\ndefmodule MyApp.HaikuAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"haiku_bot\",\n      instructions: \"You only respond in haikus.\",\n      model: \"gpt-4o\",\n      model_settings: %{\n        temperature: 0.7,\n        max_tokens: 100\n      }\n    }\n  end\n  \n  # Optional lifecycle callbacks\n  @impl true\n  def on_start(context, state) do\n    IO.puts(\"Agent starting...\")\n    {:ok, state}\n  end\nend\n```","ref":"readme.html#agents"},{"type":"extras","title":"Tools - OpenAI Agents for Elixir","doc":"Tools are functions that agents can call:\n\n```elixir\ndefmodule MyApp.Tools.Weather do\n  use OpenAI.Agents.Tool\n  \n  @impl true\n  def schema do\n    %{\n      name: \"get_weather\",\n      description: \"Get the current weather for a city\",\n      parameters: %{\n        type: \"object\",\n        properties: %{\n          city: %{type: \"string\", description: \"City name\"}\n        },\n        required: [\"city\"]\n      }\n    }\n  end\n  \n  @impl true\n  def execute(%{\"city\" => city}, _context) do\n    # In real usage, call a weather API\n    {:ok, %{temperature: 72, conditions: \"Sunny\", city: city}}\n  end\nend\n```","ref":"readme.html#tools"},{"type":"extras","title":"Context - OpenAI Agents for Elixir","doc":"Pass application state through the execution:\n\n```elixir\n# Define your context\ncontext = %{\n  user_id: \"123\",\n  session_id: \"abc\",\n  preferences: %{language: \"en\"}\n}\n\n# Pass it to the agent\n{:ok, result} = OpenAI.Agents.run(MyApp.Assistant, \"Hello\", context: context)\n\n# Access it in tools\ndefmodule MyApp.Tools.UserPreferences do\n  use OpenAI.Agents.Tool\n  \n  @impl true\n  def execute(_params, context) do\n    user_id = context.user_context.user_id\n    # Use the context data\n    {:ok, %{user_id: user_id}}\n  end\nend\n```","ref":"readme.html#context"},{"type":"extras","title":"Guardrails - OpenAI Agents for Elixir","doc":"Guardrails validate inputs and outputs to ensure safe operation:\n\n```elixir\ndefmodule MyApp.Guardrails.NoPersonalInfo do\n  use OpenAI.Agents.Guardrail\n  \n  @impl true\n  def validate_input(input, _context) do\n    if String.match?(input, ~r/ssn|social security|credit card/i) do\n      {:error, \"Cannot process personal information\", %{type: \"privacy_violation\"}}\n    else\n      :ok\n    end\n  end\n  \n  @impl true\n  def validate_output(output, _context) do\n    if String.match?(output, ~r/password|secret/i) do\n      {:error, \"Output contains sensitive information\", %{type: \"data_leak\"}}\n    else\n      :ok\n    end\n  end\nend\n\ndefmodule MyApp.SecureAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"secure_agent\",\n      instructions: \"You are a helpful assistant.\",\n      input_guardrails: [MyApp.Guardrails.NoPersonalInfo],\n      output_guardrails: [MyApp.Guardrails.NoPersonalInfo]\n    }\n  end\nend\n```","ref":"readme.html#guardrails"},{"type":"extras","title":"Handoffs - OpenAI Agents for Elixir","doc":"Agents can transfer conversations to specialized agents:\n\n```elixir\ndefmodule MyApp.Tools.TransferToSupport do\n  use OpenAI.Agents.Tool\n  \n  @impl true\n  def schema do\n    %{\n      name: \"transfer_to_support\",\n      description: \"Transfer the conversation to a support specialist\",\n      parameters: %{\n        type: \"object\",\n        properties: %{\n          reason: %{type: \"string\", description: \"Reason for transfer\"}\n        },\n        required: [\"reason\"]\n      }\n    }\n  end\n  \n  @impl true\n  def execute(%{\"reason\" => reason}, _context) do\n    {:handoff, MyApp.SupportAgent, %{transfer_reason: reason}}\n  end\nend\n\ndefmodule MyApp.SupportAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"support_agent\",\n      instructions: \"You are a technical support specialist.\"\n    }\n  end\nend\n\ndefmodule MyApp.TriageAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"triage_agent\",\n      instructions: \"Route users to appropriate specialists.\",\n      tools: [MyApp.Tools.TransferToSupport],\n      handoffs: [MyApp.SupportAgent]\n    }\n  end\nend\n```","ref":"readme.html#handoffs"},{"type":"extras","title":"Examples - OpenAI Agents for Elixir","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Example 1: Simple Q&A Agent - OpenAI Agents for Elixir","doc":"```elixir\ndefmodule MyApp.QAAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"qa_agent\",\n      instructions: \"\"\"\n      You are a helpful Q&A assistant. \n      Provide clear, accurate answers to questions.\n      If you don't know something, say so.\n      \"\"\"\n    }\n  end\nend\n\n# Usage\n{:ok, result} = OpenAI.Agents.run(MyApp.QAAgent, \"What is Elixir?\")\n```","ref":"readme.html#example-1-simple-q-a-agent"},{"type":"extras","title":"Example 2: Agent with Tools - OpenAI Agents for Elixir","doc":"```elixir\ndefmodule MyApp.MathTools do\n  use OpenAI.Agents.Tool\n  \n  @impl true\n  def schema do\n    %{\n      name: \"calculate\",\n      description: \"Perform mathematical calculations\",\n      parameters: %{\n        type: \"object\",\n        properties: %{\n          expression: %{type: \"string\"}\n        },\n        required: [\"expression\"]\n      }\n    }\n  end\n  \n  @impl true\n  def execute(%{\"expression\" => expr}, _context) do\n    # BE CAREFUL: In production, use a safe math parser!\n    try do\n      {result, _} = Code.eval_string(expr)\n      {:ok, %{result: result}}\n    rescue\n      _ -> {:error, \"Invalid expression\"}\n    end\n  end\nend\n\ndefmodule MyApp.MathTutor do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"math_tutor\",\n      instructions: \"You are a helpful math tutor. Use the calculate tool for computations.\",\n      tools: [MyApp.MathTools]\n    }\n  end\nend\n\n# Usage\n{:ok, result} = OpenAI.Agents.run(MyApp.MathTutor, \"What is 25 * 4 + 10?\")\n```","ref":"readme.html#example-2-agent-with-tools"},{"type":"extras","title":"Example 3: Multi-Agent System with Handoffs - OpenAI Agents for Elixir","doc":"```elixir\ndefmodule MyApp.SpanishAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"spanish_agent\",\n      instructions: \"You only speak Spanish. Respond to all queries in Spanish.\"\n    }\n  end\nend\n\ndefmodule MyApp.FrenchAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"french_agent\", \n      instructions: \"You only speak French. Respond to all queries in French.\"\n    }\n  end\nend\n\ndefmodule MyApp.TriageAgent do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"triage_agent\",\n      instructions: \"\"\"\n      You are a triage agent that routes conversations to the right language expert.\n      If the user wants Spanish, transfer to the Spanish agent.\n      If the user wants French, transfer to the French agent.\n      Otherwise, respond in English.\n      \"\"\",\n      handoffs: [MyApp.SpanishAgent, MyApp.FrenchAgent]\n    }\n  end\nend\n\n# Usage\n{:ok, result} = OpenAI.Agents.run(MyApp.TriageAgent, \"I need help in Spanish\")\n# Agent will hand off to SpanishAgent\n```","ref":"readme.html#example-3-multi-agent-system-with-handoffs"},{"type":"extras","title":"Example 4: Streaming Responses - OpenAI Agents for Elixir","doc":"```elixir\ndefmodule MyApp.StoryTeller do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"storyteller\",\n      instructions: \"You are a creative storyteller.\"\n    }\n  end\nend\n\n# Stream the response\nMyApp.StoryTeller\n|> OpenAI.Agents.stream(\"Tell me a story about a brave rabbit\")\n|> Stream.each(fn event ->\n  case event do\n    %OpenAI.Agents.Events.TextDelta{text: text} -> \n      # Print text as it arrives\n      IO.write(text)\n      \n    %OpenAI.Agents.Events.ToolCall{name: name} -> \n      IO.puts(\"\\n[Calling tool: #{name}]\")\n      \n    %OpenAI.Agents.Events.ResponseCompleted{usage: usage} ->\n      IO.puts(\"\\n\\nTokens used: #{usage.total_tokens}\")\n      \n    _ -> \n      :ok\n  end\nend)\n|> Stream.run()\n```","ref":"readme.html#example-4-streaming-responses"},{"type":"extras","title":"Example 5: Agents with Guardrails - OpenAI Agents for Elixir","doc":"```elixir\ndefmodule MyApp.Guardrails.MathOnly do\n  use OpenAI.Agents.Guardrail\n  \n  @impl true\n  def validate_input(input, _context) do\n    if String.match?(input, ~r/math|calculate|number|equation/i) do\n      :ok\n    else\n      {:error, \"I only help with math questions\", %{reason: \"off_topic\"}}\n    end\n  end\nend\n\ndefmodule MyApp.MathHelper do\n  use OpenAI.Agent\n  \n  @impl true\n  def configure do\n    %{\n      name: \"math_helper\",\n      instructions: \"You are a math helper. Only answer math-related questions.\",\n      input_guardrails: [MyApp.Guardrails.MathOnly]\n    }\n  end\nend\n\n# This will work\n{:ok, result} = OpenAI.Agents.run(MyApp.MathHelper, \"What is 2+2?\")\n\n# This will be rejected by the guardrail\n{:error, {:guardrail_triggered, _}} = OpenAI.Agents.run(MyApp.MathHelper, \"Tell me about dogs\")\n```","ref":"readme.html#example-5-agents-with-guardrails"},{"type":"extras","title":"Elixir-Specific Features - OpenAI Agents for Elixir","doc":"","ref":"readme.html#elixir-specific-features"},{"type":"extras","title":"1. Process-Based Isolation - OpenAI Agents for Elixir","doc":"Each agent run is isolated in its own process, providing fault tolerance:\n\n```elixir\n# If an agent crashes, it doesn't affect your application\ntask1 = OpenAI.Agents.run_async(MyAgent, \"Query 1\")\ntask2 = OpenAI.Agents.run_async(MyAgent, \"Query 2\") \n\n# Even if task1 crashes, task2 continues\n```","ref":"readme.html#1-process-based-isolation"},{"type":"extras","title":"2. Concurrent Tool Execution - OpenAI Agents for Elixir","doc":"Tools are executed in parallel automatically:\n\n```elixir\ndefmodule MyApp.SlowTool do\n  use OpenAI.Agents.Tool\n  \n  @impl true\n  def execute(_params, _context) do\n    # These will run concurrently if the agent calls multiple tools\n    Process.sleep(1000)\n    {:ok, %{data: \"result\"}}\n  end\nend\n```","ref":"readme.html#2-concurrent-tool-execution"},{"type":"extras","title":"3. GenStage-Based Streaming - OpenAI Agents for Elixir","doc":"The streaming implementation uses GenStage for proper backpressure handling:\n\n```elixir\n# The stream automatically handles backpressure\nstream = OpenAI.Agents.stream(MyAgent, \"Generate a long response\")\n\n# Process in batches with Flow (optional)\nstream\n|> Flow.from_enumerable(max_demand: 10)\n|> Flow.map(&process_event/1)\n|> Flow.run()\n```","ref":"readme.html#3-genstage-based-streaming"},{"type":"extras","title":"4. Telemetry Integration - OpenAI Agents for Elixir","doc":"Built-in telemetry for monitoring:\n\n```elixir\n# Attach to telemetry events\n:telemetry.attach_many(\n  \"my-app-handler\",\n  [\n    [:openai_agents, :run, :start],\n    [:openai_agents, :run, :stop],\n    [:openai_agents, :tool, :start],\n    [:openai_agents, :tool, :stop]\n  ],\n  &MyApp.TelemetryHandler.handle_event/4,\n  nil\n)\n```","ref":"readme.html#4-telemetry-integration"},{"type":"extras","title":"5. Supervision and Fault Tolerance - OpenAI Agents for Elixir","doc":"The library uses OTP supervision for reliability:\n\n```elixir\n# Agents run under a DynamicSupervisor\n# If a run fails, it's isolated and won't crash your system\n\n# You can also configure restart strategies\nconfig :openai_agents,\n  runner_restart_strategy: :transient,\n  max_restarts: 3\n```","ref":"readme.html#5-supervision-and-fault-tolerance"},{"type":"extras","title":"6. Registry-Based Agent Discovery - OpenAI Agents for Elixir","doc":"Agents can be discovered dynamically:\n\n```elixir\n# Register agents with custom names\ndefmodule MyApp.DynamicAgent do\n  use OpenAI.Agent\n  \n  def start_link(opts) do\n    name = Keyword.get(opts, :name)\n    Registry.register(MyApp.AgentRegistry, name, __MODULE__)\n    {:ok, self()}\n  end\nend\n\n# Find and run agents dynamically\n[{pid, module}] = Registry.lookup(MyApp.AgentRegistry, \"custom_agent\")\nOpenAI.Agents.run(module, \"Hello\")\n```","ref":"readme.html#6-registry-based-agent-discovery"},{"type":"extras","title":"API Reference - OpenAI Agents for Elixir","doc":"","ref":"readme.html#api-reference"},{"type":"extras","title":"Main Functions - OpenAI Agents for Elixir","doc":"- `OpenAI.Agents.run/3` - Run an agent synchronously\n- `OpenAI.Agents.run_async/3` - Run an agent asynchronously  \n- `OpenAI.Agents.stream/3` - Stream an agent's response","ref":"readme.html#main-functions"},{"type":"extras","title":"Options - OpenAI Agents for Elixir","doc":"All functions accept these options:\n\n- `:context` - Application-specific context\n- `:timeout` - Maximum execution time (default: 60000ms)\n- `:max_turns` - Maximum conversation turns (default: 10)\n- `:trace_id` - Custom trace ID for debugging","ref":"readme.html#options"},{"type":"extras","title":"Behaviors - OpenAI Agents for Elixir","doc":"- `OpenAI.Agent` - Define an agent\n- `OpenAI.Agents.Tool` - Define a tool\n- `OpenAI.Agents.Guardrail` - Define a guardrail","ref":"readme.html#behaviors"},{"type":"extras","title":"Configuration - OpenAI Agents for Elixir","doc":"Full configuration options in `config/config.exs`:\n\n```elixir\nconfig :openai_agents,\n  # Required\n  api_key: System.get_env(\"OPENAI_API_KEY\"),\n  \n  # Optional\n  base_url: \"https://api.openai.com/v1\",\n  default_model: \"gpt-4o\",\n  max_turns: 10,\n  timeout: 60_000,\n  \n  # Telemetry and tracing\n  trace_processors: [\n    OpenAI.Agents.Tracing.ConsoleProcessor,\n    {OpenAI.Agents.Tracing.FileProcessor, path: \"/tmp/traces\"}\n  ],\n  \n  # Pool configuration for HTTP client\n  pool_size: 10,\n  pool_timeout: 5_000\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Common Patterns - OpenAI Agents for Elixir","doc":"","ref":"readme.html#common-patterns"},{"type":"extras","title":"Error Handling - OpenAI Agents for Elixir","doc":"```elixir\ncase OpenAI.Agents.run(MyAgent, \"Hello\") do\n  {:ok, result} -> \n    IO.puts(result.output)\n    \n  {:error, {:guardrail_triggered, {guardrail, reason, metadata}}} ->\n    IO.puts(\"Guardrail #{guardrail} blocked: #{reason}\")\n    \n  {:error, {:max_turns_exceeded, turns}} ->\n    IO.puts(\"Agent exceeded #{turns} turns\")\n    \n  {:error, {:api_error, status, body}} ->\n    IO.puts(\"API error #{status}: #{body}\")\n    \n  {:error, reason} ->\n    IO.puts(\"Error: #{inspect(reason)}\")\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Examples - OpenAI Agents for Elixir","doc":"","ref":"readme.html#examples-1"},{"type":"extras","title":"Travel Booking Example - OpenAI Agents for Elixir","doc":"A comprehensive example demonstrating all major framework features through a realistic travel booking workflow:\n\n```bash\ncd examples/travel_booking\nmix deps.get\nmix run -e \"TravelBooking.main()\"\n```\n\nSee [`examples/travel_booking/README.md`](examples/travel_booking/README.md) for detailed setup and usage instructions.\n\nThis example showcases:\n- Multi-agent handoffs between specialized agents\n- Dynamic instructions based on user context\n- Tool integration for external functions\n- Guardrails for input/output validation\n- Context management across agents","ref":"readme.html#travel-booking-example"},{"type":"extras","title":"Testing Agents - OpenAI Agents for Elixir","doc":"The library includes both unit tests and integration tests:\n\n#### Running Tests\n\n```bash\n# Run unit tests only (default)\nmix test\n\n# Run integration tests that call OpenAI API\nmix test --include remote\n\n# Run only remote/integration tests\nmix test --only remote\n```\n\n**Note:** Integration tests require a valid `OPENAI_API_KEY` environment variable and will make real API calls. They are excluded by default to prevent accidental API usage and costs.\n\n#### Writing Tests\n\nFor unit tests, mock the API calls:\n\n```elixir\n# In your tests\ndefmodule MyApp.AgentTest do\n  use ExUnit.Case\n  \n  test \"agent responds correctly\" do\n    # Use Bypass for mocking API calls\n    bypass = Bypass.open()\n    \n    Application.put_env(:openai_agents, :base_url, \"http://localhost:#{bypass.port}\")\n    \n    Bypass.expect_once(bypass, \"POST\", \"/responses\", fn conn ->\n      Plug.Conn.resp(conn, 200, Jason.encode!(%{\n        output: [%{type: \"message\", content: [%{type: \"output_text\", text: \"Hello!\"}]}],\n        usage: %{total_tokens: 10}\n      }))\n    end)\n    \n    assert {:ok, result} = OpenAI.Agents.run(MyApp.Assistant, \"Hi\")\n    assert result.output == \"Hello!\"\n  end\nend\n```\n\nFor integration tests that need the real API:\n\n```elixir\ndefmodule MyApp.AgentIntegrationTest do\n  use ExUnit.Case\n  \n  # Tag the entire module as remote\n  @moduletag :remote\n  \n  test \"agent handles real conversations\" do\n    {:ok, result} = OpenAI.Agents.run(MyApp.Assistant, \"Hello\")\n    assert is_binary(result.output)\n    assert result.usage.total_tokens > 0\n  end\nend\n```","ref":"readme.html#testing-agents"},{"type":"extras","title":"Learn More - OpenAI Agents for Elixir","doc":"- [Full API Documentation](https://hexdocs.pm/openai_agents)\n- [GitHub Repository](https://github.com/yourusername/openai_agents)\n- [OpenAI Responses API Docs](https://platform.openai.com/docs)","ref":"readme.html#learn-more"},{"type":"extras","title":"License - OpenAI Agents for Elixir","doc":"MIT License - see LICENSE file for details.","ref":"readme.html#license"}],"proglang":"elixir","producer":{"name":"ex_doc","version":"0.38.2"},"content_type":"text/markdown"}